@@ -25,8 +25,8 @@ def h_file(filename):
 	"""now folders can have a signature too"""
 	st = os.stat(filename)
 	if stat.S_ISDIR(st[stat.ST_MODE]):
-		return Utils.md5(filename.encode('latin-1')).digest()
-	m = Utils.md5()
+		return Utils.md5(filename.encode('latin-1'), usedforsecurity=False).digest()
+	m = Utils.md5(usedforsecurity=False)
 	m.update(str(st.st_mtime))
 	m.update(str(st.st_size))
 	m.update(filename.encode('latin-1'))
