@@ -356,7 +356,7 @@ def check_python_headers(conf, features='pyembed pyext'):
 
 	# Try to get pythonX.Y-config
 	num = '.'.join(env.PYTHON_VERSION.split('.')[:2])
-	if dct['Py_GIL_DISABLED']:
+	if dct['Py_GIL_DISABLED'] == '1':
 		num += 't'
 	conf.find_program([''.join(pybin) + '-config', 'python%s-config' % num, 'python-config-%s' % num, 'python%sm-config' % num], var='PYTHON_CONFIG', msg="python-config", mandatory=False)
 
@@ -422,7 +422,7 @@ def check_python_headers(conf, features='pyembed pyext'):
 
 	# further simplification will be complicated
 	for name in ('python' + dct['LDVERSION'], 'python' + env.PYTHON_VERSION + 'm', 'python' + env.PYTHON_VERSION.replace('.', '')):
-		if dct['Py_GIL_DISABLED']:
+		if dct['Py_GIL_DISABLED'] == '1':
 			name += 't'
 
 		# LIBPATH_PYEMBED is already set; see if it works.
@@ -484,7 +484,7 @@ def check_python_headers(conf, features='pyembed pyext'):
 		env.append_value('CXXFLAGS_PYEXT', [ '/nologo', '/Ox', '/MD', '/W3', '/EHsc', '/DNDEBUG'])
 		env.append_value('LINKFLAGS_PYEXT', ['/DLL', '/nologo', '/INCREMENTAL:NO'])
 		# On Windows, Py_GIL_DISABLED must be defined manually, see https://docs.python.org/3/howto/free-threading-extensions.html
-		if dct['Py_GIL_DISABLED']:
+		if dct['Py_GIL_DISABLED'] == '1':
 			env.append_value('CFLAGS_PYEXT', ['/DPy_GIL_DISABLED=1'])
 			env.append_value('CXXFLAGS_PYEXT', ['/DPy_GIL_DISABLED=1'])
 
